'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var visit = _interopDefault(require('unist-util-visit'));
var Prism = _interopDefault(require('prismjs'));
var parse = _interopDefault(require('rehype-parse'));
var unified = _interopDefault(require('unified'));
var modifyChildren = _interopDefault(require('unist-util-modify-children'));

// write your code here


const codeSelector = node => node.tagName === 'code';
const preSelector = node => node.tagName === 'pre';

const parseCode = lang => (node, index, parent) => {
  if (node.type === 'text' && Prism.languages[lang]) {
    const html = Prism.highlight(node.value, Prism.languages[lang], lang);
    const tree = unified()
      .use(parse, { fragment: true })
      .parse(html);

    parent.children.splice(index, 1, ...tree.children);
    return index + tree.children.length;
  }
};

const getLang = node => {
  const lang = node.properties.className && node.properties.className[0] || '';
  return lang.replace(/^language-/, '')
};

const codeVisitor = node => {
  const lang = getLang(node);
  modifyChildren(parseCode(lang))(node);
};

const preVisitor = node => {
  visit(node, codeSelector, codeVisitor);
};

var index = () => (tree, file) => {
  visit(tree, preSelector, preVisitor);
}

module.exports = index;
